Contributing
===========

We love your input! We want to make contributing to aiopromql as easy and transparent as possible, whether it's:

* Reporting a bug
* Discussing the current state of the code
* Submitting a fix
* Proposing new features
* Becoming a maintainer

Development Process
-----------------

We use GitHub to host code, to track issues and feature requests, as well as accept pull requests.

1. Fork the repo and create your branch from `main`.
2. If you've added code that should be tested, add tests.
3. If you've changed APIs, update the documentation.
4. Ensure the test suite passes.
5. Make sure your code lints.
6. Issue that pull request!

Development Setup
---------------

1. Install development dependencies:

   .. code-block:: bash

       pip install -e .[dev]

2. Run tests:

   .. code-block:: bash

       make test-unit
       make test-docker-integration-test

3. Format and lint code:

   .. code-block:: bash

       make format
       make lint

4. Build documentation:

   .. code-block:: bash

       make docs

Any contributions you make will be under the MIT Software License
-------------------------------------------------------------

In short, when you submit code changes, your submissions are understood to be under the same `MIT License <http://choosealicense.com/licenses/mit/>`_ that covers the project. Feel free to contact the maintainers if that's a concern.

Report bugs using GitHub's `issue tracker <https://github.com/VeNIT-Lab/aiopromql/issues>`_
----------------------------------------------------------------------------------------

We use GitHub issues to track public bugs. Report a bug by `opening a new issue <https://github.com/VeNIT-Lab/aiopromql/issues/new>`_; it's that easy!

Write bug reports with detail, background, and sample code
-------------------------------------------------------

**Great Bug Reports** tend to have:

* A quick summary and/or background
* Steps to reproduce
  * Be specific!
  * Give sample code if you can.
* What you expected would happen
* What actually happens
* Notes (possibly including why you think this might be happening, or stuff you tried that didn't work)

License
-------

By contributing, you agree that your contributions will be licensed under its MIT License. 